.. This file is distributed under the MIT License. If a copy of the
.. MIT License was not distributed with this file, you can obtain one
.. at https://opensource.org/licenses/MIT.

Welcome to Django HTCPCP-TEA's documentation!
=============================================

Django HTCPCP-TEA is a `Django`_ app that implements the TEA extension to HTCPCP as defined in `RFC 7168`_.

.. _RFC 7168: https://tools.ietf.org/html/rfc7168
.. _Django: https://www.djangoproject.com/

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   config
   examples
   api
   Changelog <changelog>
